@@ -1,34 +1,37 @@
+use prae::Wrapper;
+
 prae::define! {
-    Text: String
-    adjust |t| *t = t.trim().to_owned()
+    #[derive(Debug)]
+    Text: String;
+    adjust |t| *t = t.trim().to_owned();
     validate(&'static str) |t| {
         if t.is_empty() {
             Err("provided text is empty")
         } else {
             Ok(())
         }
-    }
+    };
 }
 
-prae::define! {
-    CapText: String
-    extend TextBound
+prae::extend! {
+    #[derive(Debug)]
+    CapText: Text;
     adjust |t| {
        let mut cs = t.chars();
        *t = cs.next().unwrap().to_uppercase().collect::<String>() + cs.as_str();
-    }
+    };
 }
 
-prae::define! {
-    Sentence: String
-    extend CapTextBound
+prae::extend! {
+    #[derive(Debug)]
+    Sentence: CapText;
     validate(String) |s| {
         if s.ends_with(&['.', '!', '?'][..]) {
             Ok(())
         } else {
             Err("provided sentence has no ending punctuation mark".to_owned())
         }
-    }
+    };
 }
 
 #[test]
@@ -37,7 +40,7 @@ fn extended_works() {
     assert_eq!(t.get(), "A couple of words");
 
     let e = CapText::new(" ").unwrap_err();
-    assert_eq!(e.inner, "provided text is empty");
+    assert_eq!(e.original, "provided text is empty");
 }
 
 #[test]
@@ -46,8 +49,11 @@ fn double_extended_works() {
     assert_eq!(t.get(), "A sentence.");
 
     let e = Sentence::new(" ").unwrap_err();
-    assert_eq!(e.inner, "provided text is empty");
+    assert_eq!(e.original, "provided text is empty");
 
     let e = Sentence::new(" a sentence ").unwrap_err();
-    assert_eq!(e.inner, "provided sentence has no ending punctuation mark");
+    assert_eq!(
+        e.original,
+        "provided sentence has no ending punctuation mark"
+    );
 }
